@@ -1,9 +1,8 @@
-#![forbid(unsafe_code)]
-
 pub extern crate serde;
 pub extern crate ssh_format;
 pub extern crate vec_strings;
 
+mod handle;
 mod seq_iter;
 mod visitor;
 
@@ -13,5 +12,4 @@ pub mod open_options;
 pub mod request;
 pub mod response;
 
-pub type Handle = [u8];
-pub type HandleOwned = vec_strings::SmallArrayBox<u8, 4>;
+pub use handle::*;
